Task: Web Questions
====================
Description: Open-domain QA dataset from Web queries from Berant et al. '13. 

Link: http://www.aclweb.org/anthology/D13-1160

Tags: #WebQuestions, #All, #QA

